Type: Package
Package: diceR
Title: Diverse Cluster Ensemble in R
Version: 2.2.0
Authors@R: c(
    person("Derek", "Chiu", , "dchiu@bccrc.ca", role = c("aut", "cre")),
    person("Aline", "Talhouk", , "a.talhouk@ubc.ca", role = "aut"),
    person("Johnson", "Liu", , "gliu@bccrc.ca", role = c("ctb", "com"))
  )
Description: Performs cluster analysis using an ensemble clustering
    framework, Chiu & Talhouk (2018) <doi:10.1186/s12859-017-1996-y>.
    Results from a diverse set of algorithms are pooled together using
    methods such as majority voting, K-Modes, LinkCluE, and CSPA. There
    are options to compare cluster assignments across algorithms using
    internal and external indices, visualizations such as heatmaps, and
    significance testing for the existence of clusters.
License: MIT + file LICENSE
URL: https://github.com/AlineTalhouk/diceR/,
        https://alinetalhouk.github.io/diceR/
BugReports: https://github.com/AlineTalhouk/diceR/issues
Depends: R (>= 3.5)
Imports: abind, assertthat, class, clue, clusterSim, clv, clValid,
        dplyr (>= 0.7.5), ggplot2, infotheo, klaR, magrittr, mclust,
        methods, NMF, purrr (>= 0.2.3), RankAggreg, Rcpp, stringr,
        tidyr, yardstick
Suggests: apcluster, blockcluster, cluster, covr, dbscan, e1071,
        kernlab, knitr, kohonen, pander, poLCA, progress, RColorBrewer,
        rlang, rmarkdown, Rtsne, sigclust, testthat
LinkingTo: Rcpp
VignetteBuilder: knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.0
NeedsCompilation: yes
Packaged: 2024-01-22 20:44:12 UTC; derekchiu
Author: Derek Chiu [aut, cre],
  Aline Talhouk [aut],
  Johnson Liu [ctb, com]
Maintainer: Derek Chiu <dchiu@bccrc.ca>
Repository: CRAN
Date/Publication: 2024-01-22 21:22:46 UTC
Built: R 4.4.0; x86_64-apple-darwin20.6.0; 2024-05-07 01:32:32 UTC; unix
