# Generated by roxygen2: do not edit by hand

export(CSPA)
export(LCA)
export(LCE)
export(PAC)
export(asrs)
export(compactness)
export(consensus_cluster)
export(consensus_combine)
export(consensus_evaluate)
export(consensus_matrix)
export(cts)
export(dice)
export(ev_confmat)
export(ev_nmi)
export(graph_all)
export(graph_cdf)
export(graph_delta_area)
export(graph_heatmap)
export(graph_tracking)
export(impute_knn)
export(impute_missing)
export(k_modes)
export(majority_voting)
export(min_fnorm)
export(pcn_select)
export(pcn_simulate)
export(prepare_data)
export(relabel_class)
export(sigclust)
export(srs)
import(ggplot2)
importFrom(Rcpp,sourceCpp)
importFrom(magrittr,"%>%")
importFrom(mclust,mclustBIC)
importFrom(purrr,"%||%")
useDynLib(diceR, .registration = TRUE)
